==> qTox-1.18.3.tar.gz: qTox-1.18.3/translations/README.md <==
# Translating

Translating qTox should be easy & straightforward for anyone using
[**Weblate**](https://hosted.weblate.org/projects/qtox/qtox/).

Overall translation: [![Translation status](https://hosted.weblate.org/widgets/qtox/-/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/?utm_source=widget)

| Language                                                              | Status                                                                                                                                                        |
| --------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| [Shqip](https://hosted.weblate.org/engage/qtox/sq/)                   | [![Translation status](https://hosted.weblate.org/widgets/qtox/sq/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/sq/?utm_source=widget)               |
| [العربية](https://hosted.weblate.org/engage/qtox/ar/)                 | [![Translation status](https://hosted.weblate.org/widgets/qtox/ar/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/ar/?utm_source=widget)               |
| [Беларуская](https://hosted.weblate.org/engage/qtox/be/)              | [![Translation status](https://hosted.weblate.org/widgets/qtox/be/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/be/?utm_source=widget)               |
| [বাংলা](https://hosted.weblate.org/engage/qtox/bn/)                   | [![Translation status](https://hosted.weblate.org/widgets/qtox/bn/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/bn/?utm_source=widget)               |
| [ⵜⵎⵣⵗⵜ](https://hosted.weblate.org/engage/qtox/ber/)                  | [![Translation status](https://hosted.weblate.org/widgets/qtox/ber/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/ber/?utm_source=widget)             |
| [Български](https://hosted.weblate.org/engage/qtox/bg/)               | [![Translation status](https://hosted.weblate.org/widgets/qtox/bg/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/bg/?utm_source=widget)               |
| [中文（中国）](https://hosted.weblate.org/engage/qtox/zh_Hans/)       | [![Translation status](https://hosted.weblate.org/widgets/qtox/zh_Hans/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/zh_Hans/?utm_source=widget)     |
| [繁體中文（台灣）](https://hosted.weblate.org/engage/qtox/zh_Hant/)   | [![Translation status](https://hosted.weblate.org/widgets/qtox/zh_Hant/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/zh_Hant/?utm_source=widget)     |
| [Hrvatski](https://hosted.weblate.org/engage/qtox/hr/)                | [![Translation status](https://hosted.weblate.org/widgets/qtox/hr/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/hr/?utm_source=widget)               |
| [Čeština](https://hosted.weblate.org/engage/qtox/cs/)                 | [![Translation status](https://hosted.weblate.org/widgets/qtox/cs/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/cs/?utm_source=widget)               |
| [Dansk](https://hosted.weblate.org/engage/qtox/da/)                   | [![Translation status](https://hosted.weblate.org/widgets/qtox/da/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/da/?utm_source=widget)               |
| [Nederlands](https://hosted.weblate.org/engage/qtox/nl/)              | [![Translation status](https://hosted.weblate.org/widgets/qtox/nl/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/nl/?utm_source=widget)               |
| [Belgisch Nederlands](https://hosted.weblate.org/engage/qtox/nl_BE/)  | [![Translation status](https://hosted.weblate.org/widgets/qtox/nl_BE/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/nl_BE/?utm_source=widget)         |
| [English](https://hosted.weblate.org/engage/qtox/en/)                 | [![Translation status](https://hosted.weblate.org/widgets/qtox/en/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/en/?utm_source=widget)               |
| [English (Pirate)](https://hosted.weblate.org/engage/qtox/en@pirate/) | [![Translation status](https://hosted.weblate.org/widgets/qtox/en@pirate/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/en@pirate/?utm_source=widget) |
| [Esperanto](https://hosted.weblate.org/engage/qtox/eo/)               | [![Translation status](https://hosted.weblate.org/widgets/qtox/eo/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/eo/?utm_source=widget)               |
| [Eesti](https://hosted.weblate.org/engage/qtox/et/)                   | [![Translation status](https://hosted.weblate.org/widgets/qtox/et/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/et/?utm_source=widget)               |
| [Suomi](https://hosted.weblate.org/engage/qtox/fi/)                   | [![Translation status](https://hosted.weblate.org/widgets/qtox/fi/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/fi/?utm_source=widget)               |
| [Français](https://hosted.weblate.org/engage/qtox/fr/)                | [![Translation status](https://hosted.weblate.org/widgets/qtox/fr/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/fr/?utm_source=widget)               |
| [Galego](https://hosted.weblate.org/engage/qtox/gl/)                  | [![Translation status](https://hosted.weblate.org/widgets/qtox/gl/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/gl/?utm_source=widget)               |
| [Deutsch](https://hosted.weblate.org/engage/qtox/de/)                 | [![Translation status](https://hosted.weblate.org/widgets/qtox/de/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/de/?utm_source=widget)               |
| [Ελληνικά](https://hosted.weblate.org/engage/qtox/el/)                | [![Translation status](https://hosted.weblate.org/widgets/qtox/el/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/el/?utm_source=widget)               |
| [עברית](https://hosted.weblate.org/engage/qtox/he/)                   | [![Translation status](https://hosted.weblate.org/widgets/qtox/he/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/he/?utm_source=widget)               |
| [Magyar](https://hosted.weblate.org/engage/qtox/hu/)                  | [![Translation status](https://hosted.weblate.org/widgets/qtox/hu/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/hu/?utm_source=widget)               |
| [Íslenska](https://hosted.weblate.org/engage/qtox/is/)                | [![Translation status](https://hosted.weblate.org/widgets/qtox/is/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/is/?)                                |
| [Italiano](https://hosted.weblate.org/engage/qtox/it/)                | [![Translation status](https://hosted.weblate.org/widgets/qtox/it/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/it/?utm_source=widget)               |
| [日本語](https://hosted.weblate.org/engage/qtox/ja/)                  | [![Translation status](https://hosted.weblate.org/widgets/qtox/ja/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/ja/?utm_source=widget)               |
| [ಕನ್ನಡ](https://hosted.weblate.org/engage/qtox/kn/)                   | [![Translation status](https://hosted.weblate.org/widgets/qtox/kn/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/kn/?utm_source=widget)               |
| [한국어](https://hosted.weblate.org/engage/qtox/ko/)                  | [![Translation status](https://hosted.weblate.org/widgets/qtox/ko/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/ko/?utm_source=widget)               |
| [Latviešu](https://hosted.weblate.org/engage/qtox/lv/)                | [![Translation status](https://hosted.weblate.org/widgets/qtox/lv/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/lv/?utm_source=widget)               |
| [Lietuvių](https://hosted.weblate.org/engage/qtox/lt/)                | [![Translation status](https://hosted.weblate.org/widgets/qtox/lt/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/lt/?utm_source=widget)               |
| [Lojban](https://hosted.weblate.org/engage/qtox/jbo/)                 | [![Translation status](https://hosted.weblate.org/widgets/qtox/jbo/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/jbo/?utm_source=widget)             |
| [Македонски](https://hosted.weblate.org/engage/qtox/mk/)              | [![Translation status](https://hosted.weblate.org/widgets/qtox/mk/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/mk/?utm_source=widget)               |
| [Norsk Bokmål](https://hosted.weblate.org/engage/qtox/nb_NO/)         | [![Translation status](https://hosted.weblate.org/widgets/qtox/nb_NO/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/nb_NO/?utm_source=widget)         |
| [فارسی](https://hosted.weblate.org/engage/qtox/fa/)                   | [![Translation status](https://hosted.weblate.org/widgets/qtox/fa/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/fa/?utm_source=widget)               |
| [Polski](https://hosted.weblate.org/engage/qtox/pl/)                  | [![Translation status](https://hosted.weblate.org/widgets/qtox/pl/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/pl/?utm_source=widget)               |
| [Português](https://hosted.weblate.org/engage/qtox/pt/)               | [![Translation status](https://hosted.weblate.org/widgets/qtox/pt/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/pt/?utm_source=widget)               |
| [Português Brasileiro](https://hosted.weblate.org/engage/qtox/pt_BR/) | [![Translation status](https://hosted.weblate.org/widgets/qtox/pt_BR/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/pt_BR/?utm_source=widget)         |
| [Română](https://hosted.weblate.org/engage/qtox/ro/)                  | [![Translation status](https://hosted.weblate.org/widgets/qtox/ro/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/ro/?utm_source=widget)               |
| [Русский](https://hosted.weblate.org/engage/qtox/ru/)                 | [![Translation status](https://hosted.weblate.org/widgets/qtox/ru/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/ru/?utm_source=widget)               |
| [Српски](https://hosted.weblate.org/engage/qtox/sr/)                  | [![Translation status](https://hosted.weblate.org/widgets/qtox/sr/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/sr/?utm_source=widget)               |
| [Srpski](https://hosted.weblate.org/engage/qtox/sr_Latn/)             | [![Translation status](https://hosted.weblate.org/widgets/qtox/sr_Latn/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/sr_Latn/?utm_source=widget)     |
| [සිංහල](https://hosted.weblate.org/engage/qtox/si/)                   | [![Translation status](https://hosted.weblate.org/widgets/qtox/si/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/si/?utm_source=widget)               |
| [Slovenčina](https://hosted.weblate.org/engage/qtox/sk/)              | [![Translation status](https://hosted.weblate.org/widgets/qtox/sk/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/sk/?utm_source=widget)               |
| [Slovenščina](https://hosted.weblate.org/engage/qtox/sl/)             | [![Translation status](https://hosted.weblate.org/widgets/qtox/sl/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/sl/?utm_source=widget)               |
| [Español](https://hosted.weblate.org/engage/qtox/es/)                 | [![Translation status](https://hosted.weblate.org/widgets/qtox/es/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/es/?utm_source=widget)               |
| [Kiswahili](https://hosted.weblate.org/engage/qtox/sw/)               | [![Translation status](https://hosted.weblate.org/widgets/qtox/sw/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/sw/?utm_source=widget)               |
| [Svenska](https://hosted.weblate.org/engage/qtox/sv/)                 | [![Translation status](https://hosted.weblate.org/widgets/qtox/sv/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/sv/?utm_source=widget)               |
| [தமிழ்](https://hosted.weblate.org/engage/qtox/ta/)                   | [![Translation status](https://hosted.weblate.org/widgets/qtox/ta/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/ta/?utm_source=widget)               |
| [Türkçe](https://hosted.weblate.org/engage/qtox/tr/)                  | [![Translation status](https://hosted.weblate.org/widgets/qtox/tr/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/tr/?utm_source=widget)               |
| [Українська](https://hosted.weblate.org/engage/qtox/uk/)              | [![Translation status](https://hosted.weblate.org/widgets/qtox/uk/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/uk/?utm_source=widget)               |
| [اُردُو](https://hosted.weblate.org/engage/qtox/ur/)                  | [![Translation status](https://hosted.weblate.org/widgets/qtox/ur/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/ur/?utm_source=widget)               |
| [ئۇيغۇرچە](https://hosted.weblate.org/engage/qtox/ug/)                | [![Translation status](https://hosted.weblate.org/widgets/qtox/ug/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/ug/?utm_source=widget)               |
| [Tiếng Việt](https://hosted.weblate.org/engage/qtox/vi/)              | [![Translation status](https://hosted.weblate.org/widgets/qtox/vi/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/vi/?utm_source=widget)               |

==> qTox-1.18.4.tar.gz: qTox-1.18.4/translations/README.md <==
# Translating

Translating qTox should be easy & straightforward for anyone using
[**Weblate**](https://hosted.weblate.org/projects/qtox/qtox/).

Overall translation: [![Translation status](https://hosted.weblate.org/widgets/qtox/-/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/?utm_source=widget)

| Language                                                              | Status                                                                                                                                                        |
| --------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| [Shqip](https://hosted.weblate.org/engage/qtox/sq/)                   | [![Translation status](https://hosted.weblate.org/widgets/qtox/sq/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/sq/?utm_source=widget)               |
| [العربية](https://hosted.weblate.org/engage/qtox/ar/)                 | [![Translation status](https://hosted.weblate.org/widgets/qtox/ar/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/ar/?utm_source=widget)               |
| [Беларуская](https://hosted.weblate.org/engage/qtox/be/)              | [![Translation status](https://hosted.weblate.org/widgets/qtox/be/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/be/?utm_source=widget)               |
| [বাংলা](https://hosted.weblate.org/engage/qtox/bn/)                   | [![Translation status](https://hosted.weblate.org/widgets/qtox/bn/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/bn/?utm_source=widget)               |
| [ⵜⵎⵣⵗⵜ](https://hosted.weblate.org/engage/qtox/ber/)                  | [![Translation status](https://hosted.weblate.org/widgets/qtox/ber/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/ber/?utm_source=widget)             |
| [Български](https://hosted.weblate.org/engage/qtox/bg/)               | [![Translation status](https://hosted.weblate.org/widgets/qtox/bg/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/bg/?utm_source=widget)               |
| [中文（中国）](https://hosted.weblate.org/engage/qtox/zh_Hans/)       | [![Translation status](https://hosted.weblate.org/widgets/qtox/zh_Hans/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/zh_Hans/?utm_source=widget)     |
| [繁體中文（台灣）](https://hosted.weblate.org/engage/qtox/zh_Hant/)   | [![Translation status](https://hosted.weblate.org/widgets/qtox/zh_Hant/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/zh_Hant/?utm_source=widget)     |
| [Hrvatski](https://hosted.weblate.org/engage/qtox/hr/)                | [![Translation status](https://hosted.weblate.org/widgets/qtox/hr/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/hr/?utm_source=widget)               |
| [Čeština](https://hosted.weblate.org/engage/qtox/cs/)                 | [![Translation status](https://hosted.weblate.org/widgets/qtox/cs/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/cs/?utm_source=widget)               |
| [Dansk](https://hosted.weblate.org/engage/qtox/da/)                   | [![Translation status](https://hosted.weblate.org/widgets/qtox/da/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/da/?utm_source=widget)               |
| [Nederlands](https://hosted.weblate.org/engage/qtox/nl/)              | [![Translation status](https://hosted.weblate.org/widgets/qtox/nl/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/nl/?utm_source=widget)               |
| [Belgisch Nederlands](https://hosted.weblate.org/engage/qtox/nl_BE/)  | [![Translation status](https://hosted.weblate.org/widgets/qtox/nl_BE/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/nl_BE/?utm_source=widget)         |
| [English](https://hosted.weblate.org/engage/qtox/en/)                 | [![Translation status](https://hosted.weblate.org/widgets/qtox/en/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/en/?utm_source=widget)               |
| [English (Pirate)](https://hosted.weblate.org/engage/qtox/en@pirate/) | [![Translation status](https://hosted.weblate.org/widgets/qtox/en@pirate/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/en@pirate/?utm_source=widget) |
| [Esperanto](https://hosted.weblate.org/engage/qtox/eo/)               | [![Translation status](https://hosted.weblate.org/widgets/qtox/eo/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/eo/?utm_source=widget)               |
| [Eesti](https://hosted.weblate.org/engage/qtox/et/)                   | [![Translation status](https://hosted.weblate.org/widgets/qtox/et/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/et/?utm_source=widget)               |
| [Suomi](https://hosted.weblate.org/engage/qtox/fi/)                   | [![Translation status](https://hosted.weblate.org/widgets/qtox/fi/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/fi/?utm_source=widget)               |
| [Français](https://hosted.weblate.org/engage/qtox/fr/)                | [![Translation status](https://hosted.weblate.org/widgets/qtox/fr/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/fr/?utm_source=widget)               |
| [Galego](https://hosted.weblate.org/engage/qtox/gl/)                  | [![Translation status](https://hosted.weblate.org/widgets/qtox/gl/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/gl/?utm_source=widget)               |
| [Deutsch](https://hosted.weblate.org/engage/qtox/de/)                 | [![Translation status](https://hosted.weblate.org/widgets/qtox/de/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/de/?utm_source=widget)               |
| [Ελληνικά](https://hosted.weblate.org/engage/qtox/el/)                | [![Translation status](https://hosted.weblate.org/widgets/qtox/el/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/el/?utm_source=widget)               |
| [עברית](https://hosted.weblate.org/engage/qtox/he/)                   | [![Translation status](https://hosted.weblate.org/widgets/qtox/he/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/he/?utm_source=widget)               |
| [Magyar](https://hosted.weblate.org/engage/qtox/hu/)                  | [![Translation status](https://hosted.weblate.org/widgets/qtox/hu/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/hu/?utm_source=widget)               |
| [Íslenska](https://hosted.weblate.org/engage/qtox/is/)                | [![Translation status](https://hosted.weblate.org/widgets/qtox/is/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/is/?)                                |
| [Italiano](https://hosted.weblate.org/engage/qtox/it/)                | [![Translation status](https://hosted.weblate.org/widgets/qtox/it/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/it/?utm_source=widget)               |
| [日本語](https://hosted.weblate.org/engage/qtox/ja/)                  | [![Translation status](https://hosted.weblate.org/widgets/qtox/ja/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/ja/?utm_source=widget)               |
| [ಕನ್ನಡ](https://hosted.weblate.org/engage/qtox/kn/)                   | [![Translation status](https://hosted.weblate.org/widgets/qtox/kn/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/kn/?utm_source=widget)               |
| [한국어](https://hosted.weblate.org/engage/qtox/ko/)                  | [![Translation status](https://hosted.weblate.org/widgets/qtox/ko/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/ko/?utm_source=widget)               |
| [Latviešu](https://hosted.weblate.org/engage/qtox/lv/)                | [![Translation status](https://hosted.weblate.org/widgets/qtox/lv/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/lv/?utm_source=widget)               |
| [Lietuvių](https://hosted.weblate.org/engage/qtox/lt/)                | [![Translation status](https://hosted.weblate.org/widgets/qtox/lt/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/lt/?utm_source=widget)               |
| [Lojban](https://hosted.weblate.org/engage/qtox/jbo/)                 | [![Translation status](https://hosted.weblate.org/widgets/qtox/jbo/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/jbo/?utm_source=widget)             |
| [Kurdish (Northern)](https://hosted.weblate.org/engage/qtox/kmr/)     | [![Translation status](https://hosted.weblate.org/widgets/qtox/kmr/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/kmr/?utm_source=widget)             |
| [Македонски](https://hosted.weblate.org/engage/qtox/mk/)              | [![Translation status](https://hosted.weblate.org/widgets/qtox/mk/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/mk/?utm_source=widget)               |
| [Norsk Bokmål](https://hosted.weblate.org/engage/qtox/nb_NO/)         | [![Translation status](https://hosted.weblate.org/widgets/qtox/nb_NO/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/nb_NO/?utm_source=widget)         |
| [فارسی](https://hosted.weblate.org/engage/qtox/fa/)                   | [![Translation status](https://hosted.weblate.org/widgets/qtox/fa/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/fa/?utm_source=widget)               |
| [Polski](https://hosted.weblate.org/engage/qtox/pl/)                  | [![Translation status](https://hosted.weblate.org/widgets/qtox/pl/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/pl/?utm_source=widget)               |
| [Português](https://hosted.weblate.org/engage/qtox/pt/)               | [![Translation status](https://hosted.weblate.org/widgets/qtox/pt/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/pt/?utm_source=widget)               |
| [Português Brasileiro](https://hosted.weblate.org/engage/qtox/pt_BR/) | [![Translation status](https://hosted.weblate.org/widgets/qtox/pt_BR/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/pt_BR/?utm_source=widget)         |
| [Română](https://hosted.weblate.org/engage/qtox/ro/)                  | [![Translation status](https://hosted.weblate.org/widgets/qtox/ro/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/ro/?utm_source=widget)               |
| [Русский](https://hosted.weblate.org/engage/qtox/ru/)                 | [![Translation status](https://hosted.weblate.org/widgets/qtox/ru/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/ru/?utm_source=widget)               |
| [Српски](https://hosted.weblate.org/engage/qtox/sr/)                  | [![Translation status](https://hosted.weblate.org/widgets/qtox/sr/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/sr/?utm_source=widget)               |
| [Srpski](https://hosted.weblate.org/engage/qtox/sr_Latn/)             | [![Translation status](https://hosted.weblate.org/widgets/qtox/sr_Latn/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/sr_Latn/?utm_source=widget)     |
| [සිංහල](https://hosted.weblate.org/engage/qtox/si/)                   | [![Translation status](https://hosted.weblate.org/widgets/qtox/si/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/si/?utm_source=widget)               |
| [Slovenčina](https://hosted.weblate.org/engage/qtox/sk/)              | [![Translation status](https://hosted.weblate.org/widgets/qtox/sk/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/sk/?utm_source=widget)               |
| [Slovenščina](https://hosted.weblate.org/engage/qtox/sl/)             | [![Translation status](https://hosted.weblate.org/widgets/qtox/sl/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/sl/?utm_source=widget)               |
| [Español](https://hosted.weblate.org/engage/qtox/es/)                 | [![Translation status](https://hosted.weblate.org/widgets/qtox/es/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/es/?utm_source=widget)               |
| [Kiswahili](https://hosted.weblate.org/engage/qtox/sw/)               | [![Translation status](https://hosted.weblate.org/widgets/qtox/sw/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/sw/?utm_source=widget)               |
| [Svenska](https://hosted.weblate.org/engage/qtox/sv/)                 | [![Translation status](https://hosted.weblate.org/widgets/qtox/sv/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/sv/?utm_source=widget)               |
| [தமிழ்](https://hosted.weblate.org/engage/qtox/ta/)                   | [![Translation status](https://hosted.weblate.org/widgets/qtox/ta/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/ta/?utm_source=widget)               |
| [Türkçe](https://hosted.weblate.org/engage/qtox/tr/)                  | [![Translation status](https://hosted.weblate.org/widgets/qtox/tr/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/tr/?utm_source=widget)               |
| [Українська](https://hosted.weblate.org/engage/qtox/uk/)              | [![Translation status](https://hosted.weblate.org/widgets/qtox/uk/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/uk/?utm_source=widget)               |
| [اُردُو](https://hosted.weblate.org/engage/qtox/ur/)                  | [![Translation status](https://hosted.weblate.org/widgets/qtox/ur/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/ur/?utm_source=widget)               |
| [Venetian](https://hosted.weblate.org/engage/qtox/vec/)               | [![Translation status](https://hosted.weblate.org/widgets/qtox/vec/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/vec/?utm_source=widget)             |
| [ئۇيغۇرچە](https://hosted.weblate.org/engage/qtox/ug/)                | [![Translation status](https://hosted.weblate.org/widgets/qtox/ug/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/ug/?utm_source=widget)               |
| [Tiếng Việt](https://hosted.weblate.org/engage/qtox/vi/)              | [![Translation status](https://hosted.weblate.org/widgets/qtox/vi/svg-badge.svg)](https://hosted.weblate.org/engage/qtox/vi/?utm_source=widget)               |
